Helen Wood cheating boyfriend | Celebs | Showbiz and TV | Latest Celeb Gossip, TV, Film, Pop and Celeb News | Daily Star | Daily Star
Author: Nadia Mendoza
Description: Merry belated Christmas, 'tis the season to be jolly 'nd all that. And 'tis the season for all the dirty dawgs to get up to no good.
Date: 2014-12-29

# 'I found cheap eyelashes and texts' Helen Wood speaks out on cheating boyfriend

Merry belated Christmas, 'tis the season to be jolly 'nd all that. And 'tis the season for all the dirty dawgs to get up to no good.

By Helen Wood / Published 29th December 2014

GET SOME RESPECT! Helen Wood says NEVER tolerate a cheat [DS]

The holidays come with many positives – families, no work, copious amounts of cheese (literally, eating it and the corny movies variety) – but they also come with a lot of naughtiness.

When I say naughtiness, I don’t mean kids unwrapping their pressies early. I mean the parties where everyone is obliterated and mauling one another (with a wedding ring on their finger).

Last week, I was sat in the local as an office party was going on beside me and my mates, just minding our own biz.

Then a lad, about 25, sits down on the stool next to us before a rather trollied lass plonked her unsteady behind down on his knee.

They were both slurring their words when we overheard the girl say, "Weeeell, you've got a girlfriend and I'm not single, but so what?!" Lovely.

I especially loved her discretion, slap bang in the middle of the pub. She's basically got a wide-on over another guy while her other half was probably at home stuffing the turkey.

Stats show that cheating increases at this time of year, instead of secret Santa we have the secret s***gers too. Jokes aside, I think it's disgusting.

The classic excuse, 'it meant nothing'. Well, that's more of a f***ing insult! If someone is going to cheat, there must be some feelings or strong attraction, surely.

Another lame backtrack is blaming dropping your chinos or lifting your skirt on being drunk.

BEACH BABE: Helen snaps a selfie in Thailand [DS]

I don’t understand how anyone in their right mind gets THAT wasted that they don’t know what they're doing.

Coming from someone who every time they go out they get sloshed, I still don’t wake up the next morning thinking, 'Oh my God, who have I slept with?'

I've also never woken up after a night out thinking, 'S**t, did I s**g someone behind my partner's back last night?'

I think if I ever did wake up after doing that, I'd give up alcohol altogether and reassess my morals.

Alcohol is just used as an excuse, b*****ks do people only get these urges to cheat when under the influence. If you're going to cheat, you'll do it sober or drunk.

Despite the trolls (who really should make getting out more their primary new year resolution) blasting me with 'You can't talk, homewrecker/s**g/blah blah' – I CAN talk.

My views on cheating are extremely strong and always have been. Yeah, I've done my fair share of messing around and one-night stands, but I was never hurting anyone.

When I was younger, it didn’t really bother me if I knew a guy had a girlfriend, if I didn’t know the girl, it didn’t effect me. That was my opinion at the time.

CHRISTMAS ONESIE: Helen celebrated in style [DS]

Since getting older, my feelings have changed. I think if I gave my number out knowing that the lad has a chick, it'll bite me back on the a**e at some point in life.

Although I've been the girl to cheat with men that are occupied, I'd never be able to do that myself.

Having found cheap eyelashes, texts and lip-glosses in and around my ex’s things, it didn’t take a genius to work out what he’d been up to. Let's just say I've put that one to bed now.

Related articles

- 'He tried to strangle me' Helen Wood opens up on domestic violence
- 'They changed its nappy' Helen Wood on fetish duo who treat teddy as CHILD
- A day in the life of: Inside the 'sexual elite' swingers club with Helen Wood

If I felt in any way sexual towards another guy, and I don’t mean looking at a fittie in a bar, it's time to leave. Wanting to bed another man clearly means my current partner is not the one I want to have sex with for the rest of my life – SO WHAT IS THE POINT IN BEING THERE?!

One thing that actually grates on me, is when a couple 'move on' from cheating: how the f**k do you move on?

I don’t care if it's texting, kissing, s***ging whatever, it's all still cheating. A text usually leads to sex, otherwise why else do people do this?

You don’t start the ball rolling for a hot chocolate in Starbucks.

STAY DIGNIFIED! Helen has fallen victim to cheating [DS]

I pity girls that stick with guys that mess around, I mean, I can never ever imagine getting back into bed with a bloke who had his penis in another girl. What do you talk about?

'So, erm, did she have a Brazilian or a Hollywood?' 'Does she spit or swallow?' 'Who went on top?'

It's just bizarre, get a grip! I couldn’t even speak to a guy who had cheated on me, who had stripped me of dignity, trampled on my respect and took me for a fool.

There is no moving on from there.

With so many guys and girls in the world who are loyal, why waste your time on one who can't even keep an eyeball on you without the other wandering.

We’re approaching a new year, thank God I'm approaching it single, unlike some of the desperadoes I know who will celebrate being a mug through to 2016 and onwards, not me thanks.

Have a fab new year and keep it in your pants if you're otherwise engaged. Or if you're the victim of someone doing the dirty, you're worth more than that. Time to skedaddle.

Love always, Hels Bels xxx

#### Celebs

More

#### SIZZLING celeb babes beat the January blues by jetting to warmer climes

IT’S the most depressing time of the year.

#### Celebs

More

#### Blonde bombshell Rita Ora is ready to spice up The Voice

RITA Ora is set to join the judging panel on The Voice but it is her knockout body that is stealing the show right now.

#### Celebs

More

#### Lose 840 pounds a week on Gwyneth's crazy new diet... That's £ NOT lb

GWYNETH Paltrow has unveiled a New Year detox diet that would blow an average family’s food budget.

#### Celebs

More

#### Ray Winstone reveals his wardrobe fav: A pair of 15-year-old skintight gold trunks

HARD man actor Ray Winstone has revealed his wardrobe favourite... a pair of skintight gold trunks he has worn for nearly fifteen years.

#### Celebs

More

#### ‘It’s pathetic and disrespectful’ Fans turn on Madonna over controversial Luther King pic

MADONNA has sparked outrage after using altered images of Martin Luther King and Nelson Mandela to promote her new album.

#### Celebs

More

#### ‘My time at A&E was not alcohol related’ Katie Hopkins in New Year hospital dash

RENT-A-GOB Katie Hopkins has revealed she spent New Year’s Day in hospital.

#### Celebs

More

#### Next step nudist beach? Jodie Marsh continues boobylicious bikini display

IF you have been hiding underneath a rock for the last week – you may be unaware that Jodie Marsh's bikini body has set the world alight.

#### Celebs

More

#### Baby joy for Corrie’s Kylie as actress Paula Lane welcomes first child

CORONATION Street babe Paula Lane has given birth to a baby boy.

#### Celebs

More

#### Kim Kardashian sex tape co-star calls 911 in murder-suicide scare

THE man who made Kim Kardashian famous, musician Ray J, lodged a desperate call to emergency services in a murder-suicide scare.

#### Celebs

More

#### RiRi's ripped! Rihanna flaunts sexy six-pack in teeny bikini

CHART-TOPPING star Rihanna has just provided fans with a whole lot of gymspiration thanks to her washboard abs.

#### Celebs

More

#### Happy NUDE year! Tara Reid shares completely starkers selfie

WHILE Tara Reid is no stranger to scantily-clad solo snaps – she does normally shield her modesty with a skimpy bikini.

#### Celebs

More

#### 'One Direction to lose fans & Kimye will split' Horseface Hopkins' 2015 predictions

SAY what you want about the moaning old horseface, but at least Katie Hopkins is consistent.

#### Most popular today

- #1

  ##### Man Utd News: Big announcement, £40m Hummels torn, Ronaldo offer, Jones demands more

- #2

  ##### So Long Stevie! Gerrard says GOODBYE Liverpool, HELLO £90 million

- #3

  ##### TRANSFER NEWS: Man Utd target's deal, Arsenal and Chelsea EXITS, Liverpool eye PSG ace

- #4

  ##### EXCLUSIVE: Ex-Chelsea star Frank Lampard in talks over long-term deal at Man City

- #5

  ##### GTA 5 featured playlists Rockstar double cash all weekend